@@ -37,7 +37,6 @@
 #include <libmissioncontrol/mission-control.h>
 #include <libmissioncontrol/mc-account-monitor.h>
 #include <telepathy-glib/util.h>
-#include <libtelepathy/tp-constants.h>
 
 #include <libempathy/empathy-debug.h>
 #include <libempathy/empathy-utils.h>
@@ -47,6 +46,7 @@
 #include "empathy-profile-chooser.h"
 #include "empathy-account-widget.h"
 #include "empathy-account-widget-irc.h"
+#include "empathy-account-widget-sip.h"
 
 #define DEBUG_DOMAIN "AccountDialog"
 
@@ -85,6 +85,7 @@ typedef struct {
 
 	MissionControl   *mc;
 	McAccountMonitor *monitor;
+	gpointer          token;
 } EmpathyAccountsDialog;
 
 enum {
@@ -278,6 +279,10 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 			dialog->settings_widget =
 				empathy_account_widget_icq_new (account);
 		}
+		else if (!tp_strdiff(config_ui, "aim")) {
+			dialog->settings_widget =
+				empathy_account_widget_aim_new (account);
+		}
 		else if (!tp_strdiff (config_ui, "yahoo")) {
 			dialog->settings_widget =
 				empathy_account_widget_yahoo_new (account);
@@ -286,6 +291,10 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 			dialog->settings_widget =
 				empathy_account_widget_sip_new (account);
 		}
+		else if  (!tp_strdiff (config_ui, "groupwise")) {
+			dialog->settings_widget =
+				empathy_account_widget_groupwise_new (account);
+		}
 		else {
 			dialog->settings_widget = 
 				empathy_account_widget_generic_new (account);
@@ -308,7 +317,8 @@ accounts_dialog_update_account (EmpathyAccountsDialog *dialog,
 		gtk_widget_set_tooltip_text (dialog->image_type,
 					     mc_profile_get_display_name (profile));
 
-		text = g_strdup_printf ("<big><b>%s</b></big>", mc_account_get_display_name (account));
+		text = g_markup_printf_escaped ("<big><b>%s</b></big>",
+				mc_account_get_display_name (account));
 		gtk_label_set_markup (GTK_LABEL (dialog->label_name), text);
 		g_free (text);
 	}
@@ -955,10 +965,7 @@ accounts_dialog_destroy_cb (GtkWidget            *widget,
 	g_signal_handlers_disconnect_by_func (dialog->monitor,
 					      accounts_dialog_account_enabled_cb,
 					      dialog);
-	dbus_g_proxy_disconnect_signal (DBUS_G_PROXY (dialog->mc),
-					"AccountStatusChanged",
-					G_CALLBACK (accounts_dialog_status_changed_cb),
-					dialog);
+	empathy_disconnect_account_status_changed (dialog->token);
 
 	/* Delete incomplete accounts */
 	accounts = mc_accounts_list ();
@@ -991,6 +998,7 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 {
 	static EmpathyAccountsDialog *dialog = NULL;
 	GladeXML                    *glade;
+	gchar                       *filename;
 	GtkWidget                   *bbox;
 	GtkWidget                   *button_close;
 
@@ -1001,7 +1009,9 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 
 	dialog = g_new0 (EmpathyAccountsDialog, 1);
 
-	glade = empathy_glade_get_file ("empathy-accounts-dialog.glade",
+	filename = empathy_file_lookup ("empathy-accounts-dialog.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 				       "accounts_dialog",
 				       NULL,
 				       "accounts_dialog", &dialog->window,
@@ -1022,6 +1032,7 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 				       "button_remove", &dialog->button_remove,
 				       "button_close", &button_close,
 				       NULL);
+	g_free (filename);
 
 	empathy_glade_connect (glade,
 			      dialog,
@@ -1063,9 +1074,9 @@ empathy_accounts_dialog_show (GtkWindow *parent)
 	g_signal_connect (dialog->monitor, "account-disabled",
 			  G_CALLBACK (accounts_dialog_account_enabled_cb),
 			  dialog);
-	dbus_g_proxy_connect_signal (DBUS_G_PROXY (dialog->mc), "AccountStatusChanged",
-				     G_CALLBACK (accounts_dialog_status_changed_cb),
-				     dialog, NULL);
+	dialog->token = empathy_connect_to_account_status_changed (dialog->mc,
+						   G_CALLBACK (accounts_dialog_status_changed_cb),
+						   dialog, NULL);
 
 	accounts_dialog_model_setup (dialog);
 	accounts_dialog_setup (dialog);
