@@ -48,7 +48,6 @@
 #include "empathy-chat-view.h"
 #include "empathy-chat.h"
 #include "empathy-conf.h"
-#include "empathy-preferences.h"
 #include "empathy-theme-manager.h"
 #include "empathy-ui-utils.h"
 #include "empathy-smiley-manager.h"
@@ -70,7 +69,6 @@ struct _EmpathyChatViewPriv {
 	EmpathyTheme   *theme;
 
 	time_t         last_timestamp;
-	EmpathyChatViewBlock last_block_type;
 
 	gboolean       allow_scrolling;
 	guint          scroll_timeout;
@@ -157,12 +155,8 @@ empathy_chat_view_init (EmpathyChatView *view)
 	priv = GET_PRIV (view);
 
 	priv->buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-
-	priv->last_block_type = EMPATHY_CHAT_VIEW_BLOCK_NONE;
 	priv->last_timestamp = 0;
-
 	priv->allow_scrolling = TRUE;
-
 	priv->is_group_chat = FALSE;
 
 	g_object_set (view,
@@ -638,8 +632,6 @@ chat_view_theme_changed_cb (EmpathyThemeManager *manager,
 
 	priv = GET_PRIV (view);
 
-	priv->last_block_type = EMPATHY_CHAT_VIEW_BLOCK_NONE;
-
 	empathy_conf_get_bool (empathy_conf_get (),
 			      EMPATHY_PREFS_CHAT_THEME_CHAT_ROOM,
 			      &theme_rooms);
@@ -715,31 +707,19 @@ chat_view_avatar_cache_data_free (gpointer ptr)
 GdkPixbuf *
 empathy_chat_view_get_avatar_pixbuf_with_cache (EmpathyContact *contact)
 {
-	static GHashTable *avatar_cache = NULL;
 	AvatarData        *data;
 	EmpathyAvatar     *avatar;
 	GdkPixbuf         *tmp_pixbuf;
 	GdkPixbuf         *pixbuf = NULL;
 
-	/* Init avatar cache */
-	if (!avatar_cache) {
-		avatar_cache = g_hash_table_new_full (empathy_contact_hash,
-						      empathy_contact_equal,
-						      g_object_unref,
-						      chat_view_avatar_cache_data_free);
-	}
-
 	/* Check if avatar is in cache and if it's up to date */
 	avatar = empathy_contact_get_avatar (contact);
-	data = g_hash_table_lookup (avatar_cache, contact);
+	data = g_object_get_data (G_OBJECT (contact), "chat-view-avatar-cache");
 	if (data) {
 		if (avatar && !tp_strdiff (avatar->token, data->token)) {
 			/* We have the avatar in cache */
 			return data->pixbuf;
 		}
-
-		/* The cache is outdate */
-		g_hash_table_remove (avatar_cache, contact);
 	}
 
 	/* Avatar not in cache, create pixbuf */
@@ -757,9 +737,8 @@ empathy_chat_view_get_avatar_pixbuf_with_cache (EmpathyContact *contact)
 	data->token = g_strdup (avatar->token);
 	data->pixbuf = pixbuf;
 
-	g_hash_table_insert (avatar_cache,
-			     g_object_ref (contact),
-			     data);
+	g_object_set_data_full (G_OBJECT (contact), "chat-view-avatar-cache",
+				data, chat_view_avatar_cache_data_free);
 
 	return data->pixbuf;
 }
@@ -770,14 +749,67 @@ empathy_chat_view_new (void)
 	return g_object_new (EMPATHY_TYPE_CHAT_VIEW, NULL);
 }
 
+/* Code stolen from pidgin/gtkimhtml.c */
+static gboolean
+chat_view_scroll_cb (EmpathyChatView *view)
+{
+	EmpathyChatViewPriv *priv;
+	GtkAdjustment      *adj;
+	gdouble             max_val;
+
+	priv = GET_PRIV (view);
+	adj = GTK_TEXT_VIEW (view)->vadjustment;
+	max_val = adj->upper - adj->page_size;
+
+	g_return_val_if_fail (priv->scroll_time != NULL, FALSE);
+
+	if (g_timer_elapsed (priv->scroll_time, NULL) > MAX_SCROLL_TIME) {
+		/* time's up. jump to the end and kill the timer */
+		gtk_adjustment_set_value (adj, max_val);
+		g_timer_destroy (priv->scroll_time);
+		priv->scroll_time = NULL;
+		priv->scroll_timeout = 0;
+		return FALSE;
+	}
+
+	/* scroll by 1/3rd the remaining distance */
+	gtk_adjustment_set_value (adj, gtk_adjustment_get_value (adj) + ((max_val - gtk_adjustment_get_value (adj)) / 3));
+	return TRUE;
+}
+
+void
+empathy_chat_view_scroll_down (EmpathyChatView *view)
+{
+	EmpathyChatViewPriv *priv;
+
+	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
+
+	priv = GET_PRIV (view);
+
+	if (!priv->allow_scrolling) {
+		return;
+	}
+
+	empathy_debug (DEBUG_DOMAIN, "Scrolling down");
+
+	if (priv->scroll_time) {
+		g_timer_reset (priv->scroll_time);
+	} else {
+		priv->scroll_time = g_timer_new();
+	}
+	if (!priv->scroll_timeout) {
+		priv->scroll_timeout = g_timeout_add (SCROLL_DELAY,
+						      (GSourceFunc) chat_view_scroll_cb,
+						      view);
+	}
+}
+
 void
 empathy_chat_view_append_message (EmpathyChatView *view,
 				  EmpathyMessage  *msg)
 {
 	EmpathyChatViewPriv *priv = GET_PRIV (view);
-	EmpathyContact      *sender;
 	gboolean             bottom;
-	gboolean             from_self;
 
 	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
 	g_return_if_fail (EMPATHY_IS_MESSAGE (msg));
@@ -787,8 +819,6 @@ empathy_chat_view_append_message (EmpathyChatView *view,
 	}
 
 	bottom = chat_view_is_scrolled_down (view);
-	sender = empathy_message_get_sender (msg);
-	from_self = empathy_contact_is_user (sender);
 	
 	chat_view_maybe_trim_buffer (view);
 
@@ -797,6 +827,11 @@ empathy_chat_view_append_message (EmpathyChatView *view,
 	if (bottom) {
 		empathy_chat_view_scroll_down (view);
 	}
+
+	if (priv->last_contact) {
+		g_object_unref (priv->last_contact);
+	}
+	priv->last_contact = g_object_ref (empathy_message_get_sender (msg));
 }
 
 void
@@ -821,7 +856,10 @@ empathy_chat_view_append_event (EmpathyChatView *view,
 		empathy_chat_view_scroll_down (view);
 	}
 
-	priv->last_block_type = EMPATHY_CHAT_VIEW_BLOCK_EVENT;
+	if (priv->last_contact) {
+		g_object_unref (priv->last_contact);
+		priv->last_contact = NULL;
+	}
 }
 
 void
@@ -891,77 +929,26 @@ empathy_chat_view_append_button (EmpathyChatView *view,
 		empathy_chat_view_scroll_down (view);
 	}
 
-	priv->last_block_type = EMPATHY_CHAT_VIEW_BLOCK_INVITE;
+	if (priv->last_contact) {
+		g_object_unref (priv->last_contact);
+		priv->last_contact = NULL;
+	}
 }
 
 void
 empathy_chat_view_scroll (EmpathyChatView *view,
 			 gboolean        allow_scrolling)
 {
-	EmpathyChatViewPriv *priv;
+	EmpathyChatViewPriv *priv = GET_PRIV (view);
 
 	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
 
-	priv = GET_PRIV (view);
-
-	priv->allow_scrolling = allow_scrolling;
-
 	empathy_debug (DEBUG_DOMAIN, "Scrolling %s",
 		      allow_scrolling ? "enabled" : "disabled");
-}
 
-/* Code stolen from pidgin/gtkimhtml.c */
-static gboolean
-chat_view_scroll_cb (EmpathyChatView *view)
-{
-	EmpathyChatViewPriv *priv;
-	GtkAdjustment      *adj;
-	gdouble             max_val;
-
-	priv = GET_PRIV (view);
-	adj = GTK_TEXT_VIEW (view)->vadjustment;
-	max_val = adj->upper - adj->page_size;
-
-	g_return_val_if_fail (priv->scroll_time != NULL, FALSE);
-
-	if (g_timer_elapsed (priv->scroll_time, NULL) > MAX_SCROLL_TIME) {
-		/* time's up. jump to the end and kill the timer */
-		gtk_adjustment_set_value (adj, max_val);
-		g_timer_destroy (priv->scroll_time);
-		priv->scroll_time = NULL;
-		priv->scroll_timeout = 0;
-		return FALSE;
-	}
-
-	/* scroll by 1/3rd the remaining distance */
-	gtk_adjustment_set_value (adj, gtk_adjustment_get_value (adj) + ((max_val - gtk_adjustment_get_value (adj)) / 3));
-	return TRUE;
-}
-
-void
-empathy_chat_view_scroll_down (EmpathyChatView *view)
-{
-	EmpathyChatViewPriv *priv;
-
-	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
-
-	priv = GET_PRIV (view);
-
-	if (!priv->allow_scrolling) {
-		return;
-	}
-
-	empathy_debug (DEBUG_DOMAIN, "Scrolling down");
-
-	if (priv->scroll_time) {
-		g_timer_reset (priv->scroll_time);
-	} else {
-		priv->scroll_time = g_timer_new();
-	}
-	if (!priv->scroll_timeout) {
-		priv->scroll_timeout = g_timeout_add (SCROLL_DELAY,
-						      (GSourceFunc) chat_view_scroll_cb,
-						      view);
+	priv->allow_scrolling = allow_scrolling;
+	if (allow_scrolling) {
+		empathy_chat_view_scroll_down (view);
 	}
 }
 
@@ -996,7 +983,6 @@ empathy_chat_view_clear (EmpathyChatView *view)
 	 */
 	priv = GET_PRIV (view);
 
-	priv->last_block_type = EMPATHY_CHAT_VIEW_BLOCK_NONE;
 	priv->last_timestamp = 0;
 }
 
@@ -1512,31 +1498,6 @@ empathy_chat_view_set_last_timestamp (EmpathyChatView *view,
 	priv->last_timestamp = timestamp;
 }
 
-EmpathyChatViewBlock
-empathy_chat_view_get_last_block_type (EmpathyChatView *view)
-{
-	EmpathyChatViewPriv *priv;
-
-	g_return_val_if_fail (EMPATHY_IS_CHAT_VIEW (view), 0);
-
-	priv = GET_PRIV (view);
-
-	return priv->last_block_type;
-}
-
-void
-empathy_chat_view_set_last_block_type (EmpathyChatView      *view, 
-				       EmpathyChatViewBlock  block_type)
-{
-	EmpathyChatViewPriv *priv;
-
-	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
-
-	priv = GET_PRIV (view);
-
-	priv->last_block_type = block_type;
-}
-
 EmpathyContact *
 empathy_chat_view_get_last_contact (EmpathyChatView *view)
 {
@@ -1549,22 +1510,3 @@ empathy_chat_view_get_last_contact (EmpathyChatView *view)
 	return priv->last_contact;
 }
 
-void
-empathy_chat_view_set_last_contact (EmpathyChatView *view, EmpathyContact *contact)
-{
-	EmpathyChatViewPriv *priv;
-
-	g_return_if_fail (EMPATHY_IS_CHAT_VIEW (view));
-
-	priv = GET_PRIV (view);
-
-	if (priv->last_contact) {
-		g_object_unref (priv->last_contact);
-		priv->last_contact = NULL;
-	}
-
-	if (contact) {
-		priv->last_contact = g_object_ref (contact);
-	}
-}
-
