@@ -28,7 +28,6 @@
 #include <libempathy/empathy-debug.h>
 
 #include "empathy-ui-utils.h"
-#include "empathy-main-window.h"
 #include "empathy-theme-boxes.h"
 
 #define DEBUG_DOMAIN "FancyTheme"
@@ -528,10 +527,10 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 {
 	EmpathyThemeBoxesPriv *priv;
 	EmpathyContact        *contact;
+	EmpathyContact        *last_contact;
 	GdkPixbuf            *avatar = NULL;
 	GtkTextBuffer        *buffer;
 	const gchar          *name;
-	gboolean              header;
 	GtkTextIter           iter;
 	GtkWidget            *label1, *label2;
 	GtkTextChildAnchor   *anchor;
@@ -542,42 +541,20 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 	GtkTextIter           start;
 	GdkColor              color;
 	gboolean              parse_success;
-	gboolean              from_self;
 
 	priv = GET_PRIV (theme);
 
 	contact = empathy_message_get_sender (msg);
-	from_self = empathy_contact_is_user (contact);
+	name = empathy_contact_get_name (contact);
+	last_contact = empathy_chat_view_get_last_contact (view);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 
 	empathy_debug (DEBUG_DOMAIN, "Maybe add fancy header");
 
-	name = empathy_contact_get_name (contact);
-
-	header = FALSE;
-
 	/* Only insert a header if the previously inserted block is not the same
 	 * as this one. This catches all the different cases:
 	 */
-	if (empathy_chat_view_get_last_block_type (view) != EMPATHY_CHAT_VIEW_BLOCK_SELF &&
-	    empathy_chat_view_get_last_block_type (view) != EMPATHY_CHAT_VIEW_BLOCK_OTHER) {
-		header = TRUE;
-	}
-	else if (from_self &&
-		 empathy_chat_view_get_last_block_type (view) == EMPATHY_CHAT_VIEW_BLOCK_OTHER) {
-		header = TRUE;
-	}
-	else if (!from_self && 
-		 empathy_chat_view_get_last_block_type (view) == EMPATHY_CHAT_VIEW_BLOCK_SELF) {
-		header = TRUE;
-	}
-	else if (!from_self &&
-		 (!empathy_chat_view_get_last_contact (view) ||
-		  !empathy_contact_equal (contact, empathy_chat_view_get_last_contact (view)))) {
-		header = TRUE;
-	}
-
-	if (!header) {
+	if (last_contact && empathy_contact_equal (last_contact, contact)) {
 		return;
 	}
 
@@ -613,7 +590,7 @@ theme_boxes_maybe_append_header (EmpathyTheme        *theme,
 				 G_CALLBACK (table_size_allocate_cb),
 				 box, 0);
 
-	str = g_strdup_printf ("<b>%s</b>", name);
+	str = g_markup_printf_escaped ("<b>%s</b>", name);
 
 	label1 = g_object_new (GTK_TYPE_LABEL,
 			       "label", str,
@@ -709,14 +686,6 @@ theme_boxes_append_message (EmpathyTheme        *theme,
 					   empathy_message_get_body (message),
 					   "fancy-body", "fancy-link");
 	}
-	
-	if (empathy_contact_is_user (sender)) {
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_SELF);
-		empathy_chat_view_set_last_contact (view, NULL);
-	} else {
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_OTHER);
-		empathy_chat_view_set_last_contact (view, sender);
-	}
 }
 
 static void
@@ -741,8 +710,6 @@ theme_boxes_append_event (EmpathyTheme        *theme,
 						  "fancy-event",
 						  NULL);
 	g_free (msg);
-
-	empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_EVENT);
 }
 
 static void
@@ -805,7 +772,6 @@ theme_boxes_append_timestamp (EmpathyTheme        *theme,
 							  "fancy-time",
 							  NULL);
 
-		empathy_chat_view_set_last_block_type (view, EMPATHY_CHAT_VIEW_BLOCK_TIME);
 		empathy_chat_view_set_last_timestamp (view, timestamp);
 	}
 
