@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2004 Imendio AB
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -54,10 +54,20 @@ struct _EmpathyContactClass {
 };
 
 typedef enum {
+	EMPATHY_CAPABILITIES_NONE = 0,
 	EMPATHY_CAPABILITIES_AUDIO = 1 << 0,
 	EMPATHY_CAPABILITIES_VIDEO = 1 << 1,
+	EMPATHY_CAPABILITIES_UNKNOWN = 1 << 7
 } EmpathyCapabilities;
 
+typedef enum {
+	EMPATHY_CONTACT_READY_NONE = 0,
+	EMPATHY_CONTACT_READY_ID = 1 << 0,
+	EMPATHY_CONTACT_READY_HANDLE = 1 << 1,
+	EMPATHY_CONTACT_READY_NAME = 1 << 2,
+	EMPATHY_CONTACT_READY_ALL = (1 << 3) - 1,
+} EmpathyContactReady;
+
 GType               empathy_contact_get_type           (void) G_GNUC_CONST;
 EmpathyContact *    empathy_contact_new                (McAccount           *account);
 EmpathyContact *    empathy_contact_new_full           (McAccount           *account,
@@ -87,6 +97,7 @@ void                empathy_contact_set_handle         (EmpathyContact      *con
 EmpathyCapabilities empathy_contact_get_capabilities   (EmpathyContact      *contact);
 void                empathy_contact_set_capabilities   (EmpathyContact      *contact,
 							EmpathyCapabilities  capabilities);
+EmpathyContactReady empathy_contact_get_ready          (EmpathyContact      *contact);
 gboolean            empathy_contact_is_user            (EmpathyContact      *contact);
 void                empathy_contact_set_is_user        (EmpathyContact      *contact,
 							gboolean             is_user);
@@ -96,6 +107,9 @@ gboolean            empathy_contact_can_voip           (EmpathyContact      *con
 gboolean            empathy_contact_equal              (gconstpointer        v1,
 							gconstpointer        v2);
 guint               empathy_contact_hash               (gconstpointer        key);
+void                empathy_contact_run_until_ready    (EmpathyContact      *contact,
+							EmpathyContactReady  ready,
+							GMainLoop          **loop);
 
 G_END_DECLS
 
