@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2003-2007 Imendio AB
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007-2008 Collabora Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,8 +32,6 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
-#include <libtelepathy/tp-chan.h>
-
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mission-control.h>
 
@@ -83,11 +81,6 @@ guint        empathy_account_hash                   (gconstpointer    key);
 gboolean     empathy_account_equal                  (gconstpointer    a,
 						    gconstpointer    b);
 MissionControl *empathy_mission_control_new         (void);
-gchar *      empathy_inspect_handle                 (McAccount       *account,
-						     guint            handle,
-						     guint            handle_type);
-gchar *      empathy_inspect_channel                (McAccount       *account,
-						     TpChan          *tp_chan);
 void         empathy_call_with_contact              (EmpathyContact  *contact);
 void         empathy_call_with_contact_id           (McAccount       *account,
 						     const gchar     *contact_id);
@@ -97,6 +90,23 @@ void         empathy_chat_with_contact_id           (McAccount       *account,
 const gchar * empathy_presence_get_default_message  (McPresence       presence);
 const gchar * empathy_presence_to_str               (McPresence       presence);
 McPresence    empathy_presence_from_str             (const gchar     *str);
+gchar *       empathy_file_lookup                   (const gchar     *filename,
+						     const gchar     *subdir);
+
+typedef gboolean (*EmpathyRunUntilReadyFunc)        (GObject         *object,
+						     gpointer         user_data);
+void          empathy_run_until_ready               (gpointer         object);
+void          empathy_run_until_ready_full          (gpointer         object,
+						     const gchar     *signal,
+						     EmpathyRunUntilReadyFunc  func,
+						     gpointer         user_data,
+						     GMainLoop      **loop);
+McAccount *  empathy_channel_get_account            (TpChannel       *channel);
+gpointer      empathy_connect_to_account_status_changed (MissionControl *mc,
+							 GCallback       handler,
+							 gpointer        user_data,
+							 GClosureNotify  free_func);
+void          empathy_disconnect_account_status_changed (gpointer        token);
 
 G_END_DECLS
 
